@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# $Id: makelgc.sh 1550 2007-01-30 23:37:58Z moyogo $
+# $Id: makelgc.sh 1892 2007-06-18 21:45:40Z eugeniy $
 
 # check for files needed to generate langcover.txt and unicover.txt for LGC
 # Unicode Data
@@ -21,7 +21,8 @@ for src in *.sfd; do
   echo "$src -> $out"
   sed -e 's,FontName: DejaVu,FontName: DejaVuLGC,'\
       -e 's,FullName: DejaVu,FullName: DejaVu LGC,'\
-      -e 's,FamilyName: DejaVu,FamilyName: DejaVu LGC,' < $src > $out
+      -e 's,FamilyName: DejaVu,FamilyName: DejaVu LGC,'\
+      -e 's,"DejaVu \(\(Sans\|Serif\)*\( Condensed\| Mono\)*\( Bold\)*\( Oblique\|Italic\)*\)","DejaVu LGC \1",g' < $src > $out
 done
 cd lgc
 echo "Stripping unwanted glyphs"
@@ -39,6 +40,7 @@ while ( i < \$argc )
   SelectMore(0ufe30, 0uffef)
 #  SelectMore(0u10000, 0ueffff)
   Clear()
+
   Save(\$argv[i])
   i++
 endloop
