@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: sfdnormalize.pl 1232 2006-10-31 17:26:11Z eugeniy $
+# $Id: sfdnormalize.pl 1791 2007-05-15 19:25:40Z eugeniy $
 
 # SFD normalizer (discards GUI information from SFD files)
 # (c)2004,2005 Stepan Roh (PUBLIC DOMAIN)
@@ -23,6 +23,7 @@
 #           - discarded (temporary)
 #   ModificationTime - discarded
 #   CreationTime - discarded
+#   VWidth - discarded (for now)
 # changes making it incompatible with FF older than (approx.) 20050728:
 #   Ref     - renamed to Refer
 #   KernsSLIF
@@ -47,7 +48,8 @@ sub process_sfd_file($) {
   my %pos_glyphs_map = ();
 
   while (<SFD>) {
-    next if (/^(WinInfo|DisplaySize|HStem|VStem|NameList|ModificationTime|CreationTime):/);
+    next if (/^(WinInfo|DisplaySize|HStem|VStem|ModificationTime|CreationTime|VWidth):/);
+    s,^(NameList:).*$,$1 AGL without afii,;
     s,^Ref:,Refer:,;
     s,^KernsSLIF:,KernsSLIFO:,;
     s,^(Flags:.*?)O(.*)$,$1$2,;
@@ -62,6 +64,7 @@ sub process_sfd_file($) {
       $in_spline_set = 0;
     } elsif ($in_spline_set) {
       s/(\s+)(\S+?)(,\S+\s*)$/$1.($2 & ~4 & ~256).$3/e;
+      s/([\s^])-0(\s)/$1."0".$2/eg
     }
     if (/^BeginChars:/) {
       $in_chars = 1;
